@@ -3,7 +3,11 @@
 
 set -ex
 
+test -d lib || mkdir lib
+
+gnulib-tool --update
 intltoolize --copy --force --automake
 libtoolize --force --copy
+automake --add-missing
 autoreconf
 ./configure "$@"
